==> bitcoin-abc-0.28.9.tar.gz: bitcoin-abc-0.28.9/cashtab/src/components/Etokens/CreateToken.js <==
import React from 'react';
import PropTypes from 'prop-types';
import { WalletContext } from 'utils/context';
import { getWalletState } from 'utils/cashMethods';
import { toXec } from 'wallet';
import CreateTokenForm from './CreateTokenForm';
import { AlertMsg, SidePaddingCtn } from 'components/Common/Atoms';
import ApiError from 'components/Common/ApiError';
import { BN } from 'slp-mdm';
import { supportedFiatCurrencies } from 'config/cashtabSettings';
import appConfig from 'config/app';

const CreateToken = ({ passLoadingStatus }) => {
    const { wallet, apiError, fiatPrice, cashtabSettings } =
        React.useContext(WalletContext);
    const walletState = getWalletState(wallet);
    const { balances } = walletState;

    return (
        <>
            <SidePaddingCtn data-testid="create-token-ctn">
                {apiError && <ApiError />}
                {new BN(balances.totalBalanceInSatoshis).lt(
                    new BN(appConfig.dustSats),
                ) ? (
                    <AlertMsg data-testid="insufficient-balance-for-tokens">
                        You need at least {toXec(appConfig.dustSats).toString()}{' '}
                        {appConfig.ticker} (
                        {cashtabSettings
                            ? `${
                                  supportedFiatCurrencies[
                                      cashtabSettings.fiatCurrency
                                  ].symbol
                              }`
                            : '$'}
                        {(toXec(appConfig.dustSats) * fiatPrice).toFixed(4)}{' '}
                        {cashtabSettings
                            ? `${supportedFiatCurrencies[
                                  cashtabSettings.fiatCurrency
                              ].slug.toUpperCase()}`
                            : 'USD'}
                        ) to create a token
                    </AlertMsg>
                ) : (
                    <CreateTokenForm passLoadingStatus={passLoadingStatus} />
                )}
            </SidePaddingCtn>
        </>
    );
};

/*
passLoadingStatus must receive a default prop that is a function
in order to pass the rendering unit test in Tokens.test.js

status => {console.log(status)} is an arbitrary stub function
*/

CreateToken.defaultProps = {
    passLoadingStatus: status => {
        console.log(status);
    },
};

CreateToken.propTypes = {
    passLoadingStatus: PropTypes.func,
};

export default CreateToken;

==> bitcoin-abc-0.28.11.tar.gz: bitcoin-abc-0.28.11/cashtab/src/components/Etokens/CreateToken.js <==
// Copyright (c) 2024 The Bitcoin developers
// Distributed under the MIT software license, see the accompanying
// file COPYING or http://www.opensource.org/licenses/mit-license.php.

import React from 'react';
import PropTypes from 'prop-types';
import { WalletContext } from 'wallet/context';
import { getWalletState } from 'utils/cashMethods';
import { toXec } from 'wallet';
import CreateTokenForm from './CreateTokenForm';
import { AlertMsg, SidePaddingCtn } from 'components/Common/Atoms';
import ApiError from 'components/Common/ApiError';
import { BN } from 'slp-mdm';
import { supportedFiatCurrencies } from 'config/cashtabSettings';
import appConfig from 'config/app';

const CreateToken = ({ passLoadingStatus }) => {
    const { wallet, apiError, fiatPrice, cashtabState } =
        React.useContext(WalletContext);
    // Ensure cashtabState is not undefined before context initializes
    const { settings } =
        typeof cashtabState === 'undefined'
            ? appConfig.defaultCashtabState
            : cashtabState;
    const walletState = getWalletState(wallet);
    const { balances } = walletState;

    return (
        <>
            <SidePaddingCtn>
                {apiError && <ApiError />}
                {new BN(balances.totalBalanceInSatoshis).lt(
                    new BN(appConfig.dustSats),
                ) ? (
                    <AlertMsg>
                        You need at least {toXec(appConfig.dustSats).toString()}{' '}
                        {appConfig.ticker} (
                        {settings
                            ? `${
                                  supportedFiatCurrencies[settings.fiatCurrency]
                                      .symbol
                              }`
                            : '$'}
                        {(toXec(appConfig.dustSats) * fiatPrice).toFixed(4)}{' '}
                        {settings
                            ? `${supportedFiatCurrencies[
                                  settings.fiatCurrency
                              ].slug.toUpperCase()}`
                            : 'USD'}
                        ) to create a token
                    </AlertMsg>
                ) : (
                    <CreateTokenForm passLoadingStatus={passLoadingStatus} />
                )}
            </SidePaddingCtn>
        </>
    );
};

/*
passLoadingStatus must receive a default prop that is a function
in order to pass the rendering unit test in Tokens.test.js

status => {console.log(status)} is an arbitrary stub function
*/

CreateToken.defaultProps = {
    passLoadingStatus: status => {
        console.log(status);
    },
};

CreateToken.propTypes = {
    passLoadingStatus: PropTypes.func,
};

export default CreateToken;
